@@ -1,11 +1,9 @@
 from ._util import welcome, empty
 from .create import create
 from .populate import populate
-from .connection import connection
 from .init import init
 from .find import find
 from .show import show
 from .add import add
 from .catalog import get_uuid
-from .migration import migrate
-from .rest import run
\ No newline at end of file
+from .migration import migrate
\ No newline at end of file
