@@ -64,7 +64,8 @@ def _get_uuid(rs: ImmutableResultSet) -> str:
     Returns
     ----------
     uuid : str
-        Used for field <gmd:fileIdentifier> and field <gmd:identifier>, not repeatable.
+
+        * ISO19115: ``<gmd:fileIdentifier>`` and field ``<gmd:identifier>``, not repeatable.
 
     """
     return rs.uuid
@@ -79,8 +80,12 @@ def _get_lastUpdate(rs: ImmutableResultSet) -> str:
     Returns
     ----------
     lastUpdate : str
-        Used for field <gmd:dateStamp> and field <gmd:date> with <gmd:dateType> 'revision'
-        and field <gmd:editionDate>, str in ISO-date-format, not repeatable.
+        Character string in ISO-date-format.
+
+        * ISO 19115: ``<gmd:dateStamp>`` and field ``<gmd:date>`` with ``<gmd:dateType>`` 'revision'
+        and field ``<gmd:editionDate>``, not repeatable.
+
+        * DataCite: ``<date dateType="Updated">``
 
     """
     # if a base group exists, use the title of the base group
@@ -107,19 +112,26 @@ def _get_title(rs: ImmutableResultSet) -> str:
     Returns
     ----------
     title : str
-        Used for field <gmd:title>, not repeatable.
+
+        * ISO 19115: ``<gmd:title>``, not repeatable
+
+        * DataCite: ``<title>``
 
     """
+    title = ''
+
     # if a base group exists, use the title of the base group
     if rs.group:
         title = rs.group.title
 
     # if there is only one title / entry in the ImmutableResultSet, use its title
-    elif isinstance(rs.get('title'), str):
+    # also do this if title is None, as rs.group.title can be None
+    if isinstance(rs.get('title'), str) and not title:
         title = rs.get('title')
 
     # if there are more titles in ImmutableResultSet, a dict is returned, concatenate titles
-    elif isinstance(rs.get('title'), dict):
+    # also do this if title is None, as rs.group.title can be None
+    elif isinstance(rs.get('title'), dict) and not title:
         title = ''
         for i, _title in enumerate(rs.get('title').values()):
             title += f"Title {i+1}: {_title}\n"
@@ -136,8 +148,11 @@ def _get_publication(rs: ImmutableResultSet) -> str:
     Returns
     ----------
     publication : str
-        Used for field <gmd:date> with <gmd:dateType> 'creation', 
-        str in ISO-datae-formate, not repeatable.
+        Character string in ISO-date-format, not repeatable.
+
+        * ISO 19115: ``<gmd:date>`` with ``<gmd:dateType>`` 'creation', 
+
+        * DataCite: ``<publicationYear>`` & ``<date dateType="Created">``
 
     """
     # if a base group exists, use the publication date of the base group
@@ -163,7 +178,10 @@ def _get_version(rs: ImmutableResultSet) -> int:
     Returns
     ----------
     version: int
-        Used for field <gmd:edition>, not repeatable.
+
+        * ISO 19115: ``<gmd:edition>``, not repeatable.
+
+        * DataCite: ``<version>``
 
     """
     # if there is only one version in the ImmutableResultSet, use it
@@ -184,9 +202,13 @@ def _get_authors(rs: ImmutableResultSet) -> List[Dict]:
     Returns
     ----------
     authors: list[dict]
-        Used for field <gmd:CI_ResponsibleParty>, list of dictionaries containing the 
-        information about authors: mandatory keys are `first_name`, `last_name` and
-        `organisation_name`, repeatable.
+        List of dictionaries containing information about authors: 
+        mandatory keys are ``first_name``, ``last_name`` and ``organisation_name``.
+
+        * ISO 19115: ``<gmd:CI_ResponsibleParty>``, repeatable.
+
+        * DataCite: ``<creators>`` & ``<contributor contributorType="ContactPerson">``, only 
+        first author in ``<contributors>``
 
     """
     # rs.get('authors') gives the first author and all coAuthors
@@ -207,9 +229,9 @@ def _get_authors(rs: ImmutableResultSet) -> List[Dict]:
             for author_dict in entry_authors:
                 authors.append(
                     {
-                    'first_name': author_dict['first_name'],
-                    'last_name': author_dict['last_name'],
-                    'organisation_name': author_dict['organisation_name']
+                    'first_name': author_dict.get('first_name'),
+                    'last_name': author_dict.get('last_name'),
+                    'organisation_name': author_dict.get('organisation_name')
                 })
     
     return authors
@@ -224,7 +246,10 @@ def _get_abstract(rs: ImmutableResultSet) -> str:
     Returns
     ----------
     abstract: str
-        Used for field <gmd:abstract>, not repeatable.
+
+        * ISO 19115: ``<gmd:abstract>``, not repeatable.
+
+        * DataCite: ``<description descriptionType="Abstract">``
 
     """
     abstract = ''
@@ -250,11 +275,66 @@ def _get_details(rs: ImmutableResultSet) -> List[str]:
     Returns
     ----------
     details: list[str]
-        Details as a markdown table, currently also in field <gmd:abstract>, not repeatable.
+
+        * ISO 19115: ``<gmd:supplementalInformation>``, repeatable.
 
     """
     # create list with details_table for all entries in ImmutableResultSet
-    details = []
+    details_list = []
+
+    # if there is only one entry in the ImmutableResultSet, a list details is returned by rs.get('details')
+    if isinstance(rs.get('details'), list):
+        for detail_dict in rs.get('details'):
+            # nested details
+                if isinstance(detail_dict['value'], dict):
+                    # include top-level key of nested detail
+                    details_list.append(f"{detail_dict['key']}: nested")
+
+                    # go for nested details
+                    for k, v in detail_dict['value'].items():
+                        details_list.append(f"{detail_dict['key']}.{k}: {v}")
+                # flat details
+                else:
+                    details_list.append(f"{detail_dict['key']}: {detail_dict['value']}")
+
+    # if there are more than one entries in the ImmutableResultSet, a entry_uuid-indexed dictionary of details is returned
+    elif isinstance(rs.get('details'), dict):
+        for entry_uuid, entry_details_list in rs.get('details').items():
+            for detail_dict in entry_details_list:
+                # nested details
+                if isinstance(detail_dict['value'], dict):
+                    # include top-level key of nested detail
+                    details_list.append(f"{detail_dict['key']}: nested")
+
+                    # go for nested details
+                    for k, v in detail_dict['value'].items():
+                        details_list.append(f"{detail_dict['key']}.{k}: {v}")
+                # flat details
+                else:
+                    details_list.append(f"{detail_dict['key']}: {detail_dict['value']}")
+
+    # remove duplicate details, without changing the order (keep top level keys of nested details on top)
+    details_list = list(dict.fromkeys(details_list).keys())
+
+    return details_list
+
+
+def _get_details_table(rs: ImmutableResultSet) -> List[str]:
+    """
+    Returns the details of the ImmutableResultSet as markdown tables.
+    Details are written to XML as Markdown tables along the abstracts 
+    of ImmutableResultSet members.
+
+    Returns
+    ----------
+    details_tables: list[str]
+        Details as a markdown table.
+
+        * DataCite: ``<description descriptionType="Abstract">``
+
+    """
+    # create list with details_table for all entries in ImmutableResultSet
+    details_tables = []
     _details = {}
 
     # if there is only one entry in the ImmutableResultSet, a list details is returned by rs.get('authors')
@@ -265,7 +345,7 @@ def _get_details(rs: ImmutableResultSet) -> List[str]:
                     # include top-level detail of nested detail
                     _details[detail_dict['key']] = detail_dict.copy()
                     _details[detail_dict['key']]['value'] = 'nested'
-                    
+
                     # remove unwanted key-value pairs
                     _details[detail_dict['key']] = {key: val for key, val in _details[detail_dict['key']].items() if key in ['value', 'key', 'entry_uuid', 'description']}
 
@@ -290,7 +370,7 @@ def _get_details(rs: ImmutableResultSet) -> List[str]:
         df = pd.DataFrame(_details).T
 
         # append markdown table to details
-        details.append(df.to_markdown())
+        details_tables.append(df.to_markdown())
 
     # if there are more than one entries in the ImmutableResultSet, a entry_uuid-indexed dictionary of details is returned
     elif isinstance(rs.get('details'), dict):
@@ -301,7 +381,7 @@ def _get_details(rs: ImmutableResultSet) -> List[str]:
                     # include top-level detail of nested detail
                     _details[detail_dict['key']] = detail_dict.copy()
                     _details[detail_dict['key']]['value'] = 'nested'
-                    
+
                     # remove unwanted key-value pairs
                     _details[detail_dict['key']] = {key: val for key, val in _details[detail_dict['key']].items() if key in ['value', 'key', 'entry_uuid', 'description']}
 
@@ -326,9 +406,9 @@ def _get_details(rs: ImmutableResultSet) -> List[str]:
             df = pd.DataFrame(_details).T
 
             # append markdown table to details
-            details.append(df.to_markdown())
+            details_tables.append(df.to_markdown())
 
-    return details
+    return details_tables
 
 
 def _get_keywords(rs: ImmutableResultSet) -> List[Dict]:
@@ -341,8 +421,12 @@ def _get_keywords(rs: ImmutableResultSet) -> List[Dict]:
     Returns
     ----------
     keywords: list[dict]
-        Used for field <gmd:MD_Keywords>, list of dictionaries containing information about
-        associated keywords, mandatory keys are `full_path` and `thesaurusName`.
+        List of dictionaries containing information about associated keywords, mandatory 
+        keys are ``full_path`` and ``thesaurusName``.
+
+        * ISO 19115: ``<gmd:MD_Keywords>``
+
+        * DataCite: ``<subjects>``
 
     """
     keywords = []
@@ -414,8 +498,12 @@ def _get_licenses(rs: ImmutableResultSet) -> List[Dict]:
     Returns
     ----------
     licenses: list[dict]
-        Used for field <gmd:resourceConstraints>, list of dictionaries containing information about
-        associated licenses, mandatory keys are `link` and `short_title`.
+        List of dictionaries containing information about associated licenses, 
+        mandatory keys are ``link`` and ``short_title``.
+
+        * ISO 19115: ``<gmd:resourceConstraints>``
+
+        * DataCite: ``<rightsList>``
 
     """
     licenses = []
@@ -443,7 +531,7 @@ def _get_licenses(rs: ImmutableResultSet) -> List[Dict]:
     return licenses
 
 
-def _get_datasource_information(rs: ImmutableResultSet) -> Tuple[List[Dict], List[Dict], List[int]]:
+def _get_datasource_information(rs: ImmutableResultSet) -> Tuple[List[Dict], List[Dict], List[List[Tuple]], List[int]]:
     """
     Returns the temporal scales, the location as a bounding box and the spatial resolution 
     of the data of the ImmutableResultSet.
@@ -451,19 +539,33 @@ def _get_datasource_information(rs: ImmutableResultSet) -> Tuple[List[Dict], Lis
     Returns
     ----------
     temporal_scales: list[dict]
-        Used for field <gmd:temporalElement>, list of dictionaries containing information
-        about the temporal scale(s), mandatory keys are `temporal_extent_start`, 
-        `temporal_extent_end` and `temporal_resolution`, repeatable.
+        List of dictionaries containing information about the temporal scale(s), mandatory 
+        keys are ``temporal_extent_start``, 
+        ``temporal_extent_end`` and ``temporal_resolution``
+
+        * ISO 19115: ``<gmd:temporalElement>``,  repeatable.
+
     bbox_locations: list[dict]
-        Used for field <gmd:geographicElement>, list of dictionaries containing the support
-        points of the bounding box(es), mandatory keys are `min_lon`, `min_lat`, `max_lon`
-        and `max_lat`, repeatable.
+        List of dictionaries containing the support points of the bounding box(es), mandatory 
+        keys are ``min_lon``, ``min_lat``, ``max_lon`` and ``max_lat``.
+
+        * ISO 19115: ``<gmd:geographicElement>``, repeatable.
+
+        * DataCite: ``<geoLocationPoint>``, only used if not polygon_locations.
+
+    polygon_locations: list[list[tuple]]
+        List of tuples of Polygon coordinates.
+
+        * DataCite: ``<geoLocationPolygon>``
+
     spatial_resolutions: list[int]
-        Used for field <gmd:spatialResolution>, list of integers [m], repeatable.
+
+        * ISO 19115: ``<gmd:spatialResolution>``, list of integers [m], repeatable.
 
     """
     temporal_scales = []
     bbox_locations = []
+    polygon_locations = []
     spatial_resolutions = []
     # datasource can be empty / no datasource associated
     if not rs.get('datasource'):
@@ -486,15 +588,18 @@ def _get_datasource_information(rs: ImmutableResultSet) -> Tuple[List[Dict], Lis
                 "temporal_resolution": temporal_resolution
                 }]
 
-        # spatial extent, always as a bounding box
+        # spatial extent, bounding box for ISO export, polygon for datacite export
         # go for spatial_scale in datasource first
         if 'spatial_scale' in rs.get('datasource').keys():
             location = rs.get('datasource')['spatial_scale']['extent']
             
             # convert wkt to shapely shape to infer coordinates
             P = shapely.wkt.loads(location)
+
+            # save polygon points for datacite export
+            polygon_locations.append(list(P.exterior.coords))
             
-            # get support points of polygon
+            # get bounding box points of polygon
             min_lon, min_lat = P.exterior.coords[0][0], P.exterior.coords[0][1]
             max_lon, max_lat = P.exterior.coords[2][0], P.exterior.coords[2][1]
             
@@ -521,12 +626,15 @@ def _get_datasource_information(rs: ImmutableResultSet) -> Tuple[List[Dict], Lis
                     "temporal_extent_end": temporal_extent_end,
                     "temporal_resolution": temporal_resolution
                 })
-            # spatial_scale / bbox_location & spatial_resolution
+            # spatial_scale / bbox_location, polygon_location & spatial_resolution
             if ds_dict.get('spatial_scale'):
                 location = ds_dict['spatial_scale']['extent']
         
                 # convert wkt to shapely shape to infer coordinates
                 P = shapely.wkt.loads(location)
+
+                # save polygon points for datacite export
+                polygon_locations.append(list(P.exterior.coords))
         
                 # get support points of polygon
                 min_lon, min_lat = P.exterior.coords[0][0], P.exterior.coords[0][1]
@@ -573,13 +681,13 @@ def _get_datasource_information(rs: ImmutableResultSet) -> Tuple[List[Dict], Lis
     if not bbox_locations:
         raise ValueError("No location information associated with instance to be exported.")
 
-    return temporal_scales, bbox_locations, spatial_resolutions
+    return temporal_scales, bbox_locations, polygon_locations, spatial_resolutions
 
 
-def _parse_iso_information(entry_or_resultset: Union[Entry, ImmutableResultSet]) -> Dict:
+def _parse_export_information(entry_or_resultset: Union[Entry, ImmutableResultSet]) -> Dict:
     """
     Loads the ImmutableResultSet of the input Entry (if not already an ImmutableResultSet) 
-    and extracts the information necessary for ISO export.
+    and extracts the information necessary for ISO 19115 and DataCite export.
 
     Parameters
     ----------
@@ -588,8 +696,8 @@ def _parse_iso_information(entry_or_resultset: Union[Entry, ImmutableResultSet])
     
     Returns
     ----------
-    iso_input: dict
-        Dictionary of information 
+    export_information: dict
+        Dictionary of metadata information necessary to export metadata standards. 
 
     """
     if not isinstance(entry_or_resultset, ImmutableResultSet):
@@ -619,9 +727,12 @@ def _parse_iso_information(entry_or_resultset: Union[Entry, ImmutableResultSet])
     # abstract
     abstract = _get_abstract(rs)
 
-    # details_table, put details into field <abstract> as markdown table for now
+    # details
     details = _get_details(rs)
 
+    # details_tables
+    details_tables = _get_details_table(rs)
+
     # keywords (full_path, thesaurusName.title)
     keywords = _get_keywords(rs)
 
@@ -629,16 +740,17 @@ def _parse_iso_information(entry_or_resultset: Union[Entry, ImmutableResultSet])
     licenses = _get_licenses(rs)
 
     ### datasource (spatial_scale.resolution, spatial_scale.extent/bbox_location, temporal_scale.extent, temporal_scale.resolution)
-    temporal_scales, bbox_locations, spatial_resolutions = _get_datasource_information(rs)
+    temporal_scales, bbox_locations, polygon_locations, spatial_resolutions = _get_datasource_information(rs)
 
-    # save everything in dict
-    iso_input = {
+    # save everything to dict
+    export_information = {
         'uuid': uuid, 'lastUpdate': lastUpdate, 'publication': publication, 'version': version, 'title': title, 
-        'authors': authors, 'abstract': abstract, 'details': details, 'keywords': keywords, 'licenses': licenses,
-        'temporal_scales': temporal_scales, 'bbox_locations': bbox_locations, 'spatial_resolutions': spatial_resolutions
+        'authors': authors, 'abstract': abstract, 'details': details, 'details_tables': details_tables,
+        'keywords': keywords, 'licenses': licenses, 'temporal_scales': temporal_scales, 
+        'bbox_locations': bbox_locations, 'polygon_locations': polygon_locations, 'spatial_resolutions': spatial_resolutions
         }
 
-    return iso_input
+    return export_information
 
 
 def _validate_xml(xml: str) -> bool:
